@@ -4,7 +4,11 @@ import datetime
 
 import django
 from django import forms
-from django.forms.util import to_current_timezone
+try:
+    from django.forms.utils import to_current_timezone
+except ImportError:
+    # Fall back to old module name for Django <= 1.5
+    from django.forms.util import to_current_timezone
 from django.forms.widgets import FILE_INPUT_CONTRADICTION
 from django.conf import settings
 from django.template import loader
@@ -44,6 +48,9 @@ class Input(Widget):
         datalist = kwargs.pop('datalist', None)
         if datalist is not None:
             self.datalist = datalist
+        template_name = kwargs.pop('template_name', None)
+        if template_name is not None:
+            self.template_name = template_name
         super(Input, self).__init__(*args, **kwargs)
         self.context_instance = None
 
@@ -91,9 +98,12 @@ class Input(Widget):
         return context
 
     def render(self, name, value, attrs=None, **kwargs):
+        template_name = kwargs.pop('template_name', None)
+        if template_name is None:
+            template_name = self.template_name
         context = self.get_context(name, value, attrs=attrs or {}, **kwargs)
         return loader.render_to_string(
-            self.template_name,
+            template_name,
             dictionary=context,
             context_instance=self.context_instance)
 
